@@ -26,7 +26,7 @@ setMethod(".gseparator",
             if (!is.null(container)) {
               if(is.logical(container) && container == TRUE)
                 container = gwindow(visible=TRUE)
-              add(container, obj)
+              add(container, obj,...)
             }
 
             invisible(obj)
